@@ -10,11 +10,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, Gio, GLib
+from gi.repository import Gtk, Gio, GLib, Gdk
 
 from gettext import gettext as _
 
 from urllib.parse import urlparse
+from random import randint
 
 from lollypop.define import App, Type, ResponsiveType
 from lollypop.objects import Album
@@ -63,6 +64,11 @@ class Container(Gtk.Overlay):
                                 self.__update_playlists)
         self.add(self.__paned_main_list)
 
+        # Show donation notification
+        if App().settings.get_value("show-donation"):
+            GLib.timeout_add_seconds(randint(3600, 7200),
+                                     self.__show_donation)
+
     def update_list_one(self, updater=None):
         """
             Update list one
@@ -573,10 +579,10 @@ class Container(Gtk.Overlay):
             if files:
                 device_view = DeviceView(device)
                 device_view.populate()
-                self.__stack.add_named(child, device.uri)
+                self.__stack.add_named(device_view, device.uri)
             else:
                 device_view = DeviceLocked()
-                self.__stack.add(child)
+                self.__stack.add(device_view)
             device_view.show()
         return device_view
 
@@ -726,8 +732,7 @@ class Container(Gtk.Overlay):
             return
         parsed = urlparse(uri)
         is_removable = parsed.scheme == "file" and\
-            mount.can_eject() and\
-            App().settings.get_value("sync-to-usb-disks")
+            Type.USB_DISKS in App().settings.get_value("shown-album-lists")
         if is_removable or parsed.scheme == "mtp":
             self.__devices_index -= 1
             dev = Device()
@@ -753,6 +758,28 @@ class Container(Gtk.Overlay):
                 del self.__devices[dev.id]
             break
 
+    def __show_donation(self):
+        """
+            Show a notification telling user to donate a little
+        """
+        from lollypop.app_notification import AppNotification
+        notification = AppNotification(
+            _("Please consider a donation to the project"),
+            [_("PayPal"), _("Liberapay")],
+            [lambda: Gtk.show_uri_on_window(
+                App().window,
+                "https://www.paypal.me/lollypopgnome",
+                Gdk.CURRENT_TIME),
+             lambda: Gtk.show_uri_on_window(
+                App().window,
+                "https://liberapay.com/gnumdk",
+                Gdk.CURRENT_TIME)])
+        self.add_overlay(notification)
+        notification.show()
+        notification.set_reveal_child(True)
+        App().settings.set_value("show-donation",
+                                 GLib.Variant("b", False))
+
     def __on_list_one_selected(self, selection_list):
         """
             Update view based on selected object
@@ -859,8 +886,8 @@ class Container(Gtk.Overlay):
             self.__update_lists(App().scanner)
             from lollypop.app_notification import AppNotification
             notification = AppNotification(_("New tracks available"),
-                                           _("Refresh"),
-                                           lambda: self.reload_view())
+                                           [_("Refresh")],
+                                           [lambda: self.reload_view()])
             self.add_overlay(notification)
             notification.show()
             notification.set_reveal_child(True)
