@@ -20,7 +20,6 @@ from lollypop.player_queue import QueuePlayer
 from lollypop.player_linear import LinearPlayer
 from lollypop.player_shuffle import ShufflePlayer
 from lollypop.player_radio import RadioPlayer
-from lollypop.player_externals import ExternalsPlayer
 from lollypop.player_playlist import PlaylistPlayer
 from lollypop.radios import Radios
 from lollypop.objects import Track, Album
@@ -28,7 +27,7 @@ from lollypop.define import App, Type, NextContext, LOLLYPOP_DATA_PATH, Shuffle
 
 
 class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
-             LinearPlayer, ShufflePlayer, ExternalsPlayer):
+             LinearPlayer, ShufflePlayer):
     """
         Player object used to manage playback and playlists
     """
@@ -43,7 +42,6 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
         ShufflePlayer.__init__(self)
         PlaylistPlayer.__init__(self)
         RadioPlayer.__init__(self)
-        ExternalsPlayer.__init__(self)
         self.update_crossfading()
         self.__do_not_update_next = False
         App().settings.connect("changed::playback", self.__on_playback_changed)
@@ -100,7 +98,7 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
             @param index as int
         """
         # We are not playing a user playlist anymore
-        self._playlist_track_ids = []
+        self._playlist_tracks = []
         self._playlist_ids = []
         # We do not shuffle when user add an album
         self._albums_backup = []
@@ -148,7 +146,7 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
             self.set_party(False)
         self.reset_history()
         # We are not playing a user playlist anymore
-        self._playlist_track_ids = []
+        self._playlist_tracks = []
         self._playlist_ids = []
         if App().settings.get_enum("shuffle") == Shuffle.TRACKS:
             track = choice(album.tracks)
@@ -166,10 +164,10 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
         """
         self._albums = []
         album_ids = []
-        ShufflePlayer.reset_history(self)
+        self.reset_history()
 
         # We are not playing a user playlist anymore
-        self._playlist_track_ids = []
+        self._playlist_tracks = []
         self._playlist_ids = []
         # We are in all artists
         if (genre_ids and genre_ids[0] == Type.ALL) or\
@@ -221,8 +219,6 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
             if album.id == track.album.id:
                 index = album.track_ids.index(track.id)
                 track = album.tracks[index]
-        # Shuffle album list if needed
-        self.shuffle_albums(True)
         self.load(track)
 
     def clear_albums(self):
@@ -324,27 +320,21 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
             Set previous track
         """
         try:
+            # Same track
             if App().settings.get_enum("playback") == NextContext.REPEAT_TRACK:
-                self._prev_track = self._current_track
+                prev_track = self._current_track
+            # Look at shuffle
             else:
-                # Look at externals
-                self._prev_track = ExternalsPlayer.prev(self)
-
-            # Look at radio
-            if self._prev_track.id is None:
-                self._prev_track = RadioPlayer.prev(self)
+                prev_track = ShufflePlayer.prev(self)
 
             # Look at user playlist then
-            if self._prev_track.id is None:
-                self._prev_track = PlaylistPlayer.prev(self)
-
-            # Look at shuffle
-            if self._prev_track.id is None:
-                self._prev_track = ShufflePlayer.prev(self)
+            if prev_track.id is None:
+                prev_track = PlaylistPlayer.prev(self)
 
             # Get a linear track then
-            if self._prev_track.id is None:
-                self._prev_track = LinearPlayer.prev(self)
+            if prev_track.id is None:
+                prev_track = LinearPlayer.prev(self)
+            self._prev_track = prev_track
             self.emit("prev-changed")
         except Exception as e:
             print("Player::set_prev():", e)
@@ -359,28 +349,21 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
             # Reset finished context
             self._next_context = NextContext.NONE
 
+            # Same track
             if App().settings.get_enum("playback") == NextContext.REPEAT_TRACK:
                 next_track = self._current_track
-            else:
-                # Look at externals
-                next_track = ExternalsPlayer.next(self)
-
-            # Look at radio
-            if next_track.id is None:
-                next_track = RadioPlayer.next(self)
-
             # Look first at user queue
-            if next_track.id is None:
+            else:
                 next_track = QueuePlayer.next(self)
 
+            # Look at shuffle
+            if next_track.id is None:
+                next_track = ShufflePlayer.next(self)
+
             # Look at user playlist then
             if next_track.id is None:
                 next_track = PlaylistPlayer.next(self, force)
 
-            # Get a random album/track then
-            if next_track.id is None:
-                next_track = ShufflePlayer.next(self)
-
             # Get a linear track then
             if next_track.id is None:
                 next_track = LinearPlayer.next(self)
