@@ -43,7 +43,7 @@ class ShownAlbumlists:
             if get_all or Type.RANDOMS in wanted:
                 lists.append((Type.RANDOMS, _("Random albums")))
             if get_all or Type.NEVER in wanted:
-                lists.append((Type.NEVER, _("Never played albums")))
+                lists.append((Type.NEVER, _("Unplayed albums")))
             if get_all or Type.PLAYLISTS in wanted:
                 lists.append((Type.PLAYLISTS, _("Playlists")))
             if get_all or Type.RADIOS in wanted:
@@ -56,6 +56,8 @@ class ShownAlbumlists:
         if get_all or (mask & SelectionList.Type.COMPILATIONS and
                        Type.COMPILATIONS in wanted):
             lists.append((Type.COMPILATIONS, _("Compilations")))
+        if get_all:
+            lists.append((Type.USB_DISKS, _("USB disks")))
         return lists
 
 
@@ -77,7 +79,7 @@ class ShownPlaylists:
         if get_all or Type.RECENTS in wanted:
             lists.append((Type.RECENTS, _("Recently played")))
         if get_all or Type.NEVER in wanted:
-            lists.append((Type.NEVER, _("Never played")))
+            lists.append((Type.NEVER, _("Unplayed")))
         if get_all or Type.RANDOMS in wanted:
             lists.append((Type.RANDOMS, _("Random tracks")))
         if get_all or Type.NOPARTY in wanted:
@@ -387,6 +389,7 @@ class SelectionList(Gtk.Overlay):
             @param object id as int
         """
         self.__to_select_ids = []
+        _ids = list(ids)
         if ids:
             try:
                 # Check if items are available for selection
@@ -395,10 +398,10 @@ class SelectionList(Gtk.Overlay):
                     for item in self.__model:
                         if item[0] == i:
                             items.append(item)
-                            ids.remove(i)
+                            _ids.remove(i)
                 # Select later
-                if ids:
-                    self.__to_select_ids = ids
+                if _ids:
+                    self.__to_select_ids = _ids
                 else:
                     for item in items:
                         self.__selection.select_iter(item.iter)
@@ -410,7 +413,7 @@ class SelectionList(Gtk.Overlay):
                                                    0, 0)
             except:
                 self.__last_motion_event = None
-                self.__to_select_ids = ids
+                self.__to_select_ids = _ids
         else:
             self.__selection.unselect_all()
 
